mtd/fs/jffs2 nodelist.c,1.97,1.98

Artem Bityuckiy dedekind at infradead.org
Sun Jul 10 11:15:36 EDT 2005


Update of /home/cvs/mtd/fs/jffs2
In directory phoenix.infradead.org:/tmp/cvs-serv3159

Modified Files:
	nodelist.c 
Log Message:
[JFFS2] Rename the jffs2_add_tn_to_list() function to jffs2_add_tn_to_tree().

We recently changed the method of collecting and sorting of
tmp_dnode object and now we're using a temporary RB-tree
instead of a temporary list. Rename the jffs2_add_tn_to_list()
function correspondingly. Also update its heading comments.


Index: nodelist.c
===================================================================
RCS file: /home/cvs/mtd/fs/jffs2/nodelist.c,v
retrieving revision 1.97
retrieving revision 1.98
diff -u -r1.97 -r1.98
--- nodelist.c	6 Jul 2005 15:18:41 -0000	1.97
+++ nodelist.c	10 Jul 2005 15:15:32 -0000	1.98
@@ -55,11 +55,11 @@
 	});
 }
 
-/* Put a new tmp_dnode_info into the list, keeping the list in 
-   order of increasing version
-*/
-
-static void jffs2_add_tn_to_list(struct jffs2_tmp_dnode_info *tn, struct rb_root *list)
+/* 
+ * Put a new tmp_dnode_info into the temporaty RB-tree, keeping the list in 
+ * order of increasing version.
+ */
+static void jffs2_add_tn_to_tree(struct jffs2_tmp_dnode_info *tn, struct rb_root *list)
 {
 	struct rb_node **p = &list->rb_node;
 	struct rb_node * parent = NULL;
@@ -420,7 +420,7 @@
 			D1(printk(KERN_DEBUG "dnode @%08x: ver %u, offset %04x, dsize %04x\n",
 				  ref_offset(ref), je32_to_cpu(node.i.version),
 				  je32_to_cpu(node.i.offset), je32_to_cpu(node.i.dsize)));
-			jffs2_add_tn_to_list(tn, &ret_tn);
+			jffs2_add_tn_to_tree(tn, &ret_tn);
 			break;
 
 		default:





More information about the linux-mtd-cvs mailing list